@@ -3,13 +3,12 @@ use POSIX qw(:sys_wait_h);
 use Proc::Fork;
 use Carp;
 use IO::Pipe;
-use IO::Handle;
 use strict;
 use warnings;
 use 5.010;
 
 
-our $VERSION = '0.1';
+our $VERSION = '0.2';
 
 
 sub new {
@@ -23,7 +22,8 @@ sub new {
 sub _init {
     my $self = shift;
     $self->{max_kids} //= 4;
-    $self->{ipc} //= 0; #ipc off by default        
+    $self->{ipc} //= 0; # ipc off by default
+    $self->{non_blocking} = 1;        
 }                          
 
 
@@ -34,6 +34,13 @@ sub max_kids {
 }
 
 
+sub non_blocking {
+    my ($self, $n) = @_;
+    $n // return $self->{non_blocking};
+    $self->{non_blocking} = $n;
+} 
+
+
 sub ipc {
     my ($self, $n) = @_;
     $n // return $self->{ipc};
@@ -47,6 +54,7 @@ sub fmap {
     my @rs = ();  # result set of child return values
     my $max = $self->max_kids;
     my $ipc = $self->ipc;
+    my $non_blocking = $self->non_blocking;
     for my $proc (@_) {
         my $pipe = $ipc ? IO::Pipe->new : {};
         # max kids?
@@ -66,6 +74,9 @@ sub fmap {
                 $pids{$kid}++;
                 if ($ipc) {
                     $pipe->reader();
+                    if ($non_blocking) {
+                        $pipe->blocking(0);
+                    }
                     while(<$pipe>) {
                         push @rs, $_;
                     }
@@ -174,7 +185,11 @@ Maximum number of kids allowed in the pool. The default is 4.
 
 =item B<ipc>
 
-Set IPC on (blocking)/off state. IPC is off by default.
+Set IPC on/off state. IPC is off by default.
+
+=item B<non_blocking>
+
+Defaults to true. If IPC is on and non_blocking == 1, then $pipe->blocking(0).
 
 =back
 
@@ -190,6 +205,12 @@ Turn on/off inter-process communication.
 
 max_kids setter/getter.
 
+=head2 non_blocking
+
+    $p->non_blocking(1)
+
+If IPC is on, then set IO::Pipe blocking state.
+
 =head2 fmap
 
     my @rs = $p->fmap(\&foo,@x);
